package cn.com.infosec.asn1.sec;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.asn1.x9.X9ECParametersHolder;
import cn.com.infosec.util.Strings;
import cn.com.infosec.util.encoders.Hex;
import java.math.BigInteger;
import java.util.Enumeration;
import java.util.Hashtable;

public class SECNamedCurves {
   static X9ECParametersHolder secp112r1 = new SECNamedCurves$1();
   static X9ECParametersHolder secp112r2 = new SECNamedCurves$2();
   static X9ECParametersHolder secp128r1 = new SECNamedCurves$3();
   static X9ECParametersHolder secp128r2 = new SECNamedCurves$4();
   static X9ECParametersHolder secp160k1 = new SECNamedCurves$5();
   static X9ECParametersHolder secp160r1 = new SECNamedCurves$6();
   static X9ECParametersHolder secp160r2 = new SECNamedCurves$7();
   static X9ECParametersHolder secp192k1 = new SECNamedCurves$8();
   static X9ECParametersHolder secp192r1 = new SECNamedCurves$9();
   static X9ECParametersHolder secp224k1 = new SECNamedCurves$10();
   static X9ECParametersHolder secp224r1 = new SECNamedCurves$11();
   static X9ECParametersHolder secp256k1 = new SECNamedCurves$12();
   static X9ECParametersHolder secp256r1 = new SECNamedCurves$13();
   static X9ECParametersHolder secp384r1 = new SECNamedCurves$14();
   static X9ECParametersHolder secp521r1 = new SECNamedCurves$15();
   static X9ECParametersHolder sect113r1 = new SECNamedCurves$16();
   static X9ECParametersHolder sect113r2 = new SECNamedCurves$17();
   static X9ECParametersHolder sect131r1 = new SECNamedCurves$18();
   static X9ECParametersHolder sect131r2 = new SECNamedCurves$19();
   static X9ECParametersHolder sect163k1 = new SECNamedCurves$20();
   static X9ECParametersHolder sect163r1 = new SECNamedCurves$21();
   static X9ECParametersHolder sect163r2 = new SECNamedCurves$22();
   static X9ECParametersHolder sect193r1 = new SECNamedCurves$23();
   static X9ECParametersHolder sect193r2 = new SECNamedCurves$24();
   static X9ECParametersHolder sect233k1 = new SECNamedCurves$25();
   static X9ECParametersHolder sect233r1 = new SECNamedCurves$26();
   static X9ECParametersHolder sect239k1 = new SECNamedCurves$27();
   static X9ECParametersHolder sect283k1 = new SECNamedCurves$28();
   static X9ECParametersHolder sect283r1 = new SECNamedCurves$29();
   static X9ECParametersHolder sect409k1 = new SECNamedCurves$30();
   static X9ECParametersHolder sect409r1 = new SECNamedCurves$31();
   static X9ECParametersHolder sect571k1 = new SECNamedCurves$32();
   static X9ECParametersHolder sect571r1 = new SECNamedCurves$33();
   static final Hashtable objIds = new Hashtable();
   static final Hashtable curves = new Hashtable();
   static final Hashtable names = new Hashtable();

   static {
      X9ECParametersHolder var0 = secp112r1;
      defineCurve("secp112r1", SECObjectIdentifiers.secp112r1, var0);
      var0 = secp112r2;
      defineCurve("secp112r2", SECObjectIdentifiers.secp112r2, var0);
      var0 = secp128r1;
      defineCurve("secp128r1", SECObjectIdentifiers.secp128r1, var0);
      var0 = secp128r2;
      defineCurve("secp128r2", SECObjectIdentifiers.secp128r2, var0);
      var0 = secp160r1;
      defineCurve("secp160r1", SECObjectIdentifiers.secp160r1, var0);
      var0 = secp160r2;
      defineCurve("secp160r2", SECObjectIdentifiers.secp160r2, var0);
      var0 = secp192r1;
      defineCurve("secp192r1", SECObjectIdentifiers.secp192r1, var0);
      var0 = secp224r1;
      defineCurve("secp224r1", SECObjectIdentifiers.secp224r1, var0);
      var0 = secp256r1;
      defineCurve("secp256r1", SECObjectIdentifiers.secp256r1, var0);
      var0 = secp384r1;
      defineCurve("secp384r1", SECObjectIdentifiers.secp384r1, var0);
      var0 = secp521r1;
      defineCurve("secp521r1", SECObjectIdentifiers.secp521r1, var0);
      var0 = sect113r1;
      defineCurve("sect113r1", SECObjectIdentifiers.sect113r1, var0);
      var0 = sect113r2;
      defineCurve("sect113r2", SECObjectIdentifiers.sect113r2, var0);
      var0 = sect131r1;
      defineCurve("sect131r1", SECObjectIdentifiers.sect131r1, var0);
      var0 = sect131r2;
      defineCurve("sect131r2", SECObjectIdentifiers.sect131r2, var0);
      var0 = sect163k1;
      defineCurve("sect163k1", SECObjectIdentifiers.sect163k1, var0);
      var0 = sect163r1;
      defineCurve("sect163r1", SECObjectIdentifiers.sect163r1, var0);
      var0 = sect163r2;
      defineCurve("sect163r2", SECObjectIdentifiers.sect163r2, var0);
      var0 = sect193r1;
      defineCurve("sect193r1", SECObjectIdentifiers.sect193r1, var0);
      var0 = sect193r2;
      defineCurve("sect193r2", SECObjectIdentifiers.sect193r2, var0);
      var0 = sect233k1;
      defineCurve("sect233k1", SECObjectIdentifiers.sect233k1, var0);
      var0 = sect233r1;
      defineCurve("sect233r1", SECObjectIdentifiers.sect233r1, var0);
      var0 = sect239k1;
      defineCurve("sect239k1", SECObjectIdentifiers.sect239k1, var0);
      var0 = sect283k1;
      defineCurve("sect283k1", SECObjectIdentifiers.sect283k1, var0);
      var0 = sect283r1;
      defineCurve("sect283r1", SECObjectIdentifiers.sect283r1, var0);
      var0 = sect409k1;
      defineCurve("sect409k1", SECObjectIdentifiers.sect409k1, var0);
      var0 = sect409r1;
      defineCurve("sect409r1", SECObjectIdentifiers.sect409r1, var0);
      var0 = sect571k1;
      defineCurve("sect571k1", SECObjectIdentifiers.sect571k1, var0);
      var0 = sect571r1;
      defineCurve("sect571r1", SECObjectIdentifiers.sect571r1, var0);
   }

   private static BigInteger fromHex(String hex) {
      return new BigInteger(1, Hex.decode(hex));
   }

   static void defineCurve(String name, DERObjectIdentifier oid, X9ECParametersHolder holder) {
      objIds.put(name, oid);
      names.put(oid, name);
      curves.put(oid, holder);
   }

   public static X9ECParameters getByName(String name) {
      DERObjectIdentifier name1;
      return (name1 = (DERObjectIdentifier)objIds.get(Strings.toLowerCase(name))) != null ? getByOID(name1) : null;
   }

   public static X9ECParameters getByOID(DERObjectIdentifier oid) {
      X9ECParametersHolder oid1;
      return (oid1 = (X9ECParametersHolder)curves.get(oid)) != null ? oid1.getParameters() : null;
   }

   public static DERObjectIdentifier getOID(String name) {
      return (DERObjectIdentifier)objIds.get(Strings.toLowerCase(name));
   }

   public static String getName(DERObjectIdentifier oid) {
      return (String)names.get(oid);
   }

   public static Enumeration getNames() {
      return objIds.keys();
   }

   // $FF: synthetic method
   static BigInteger access$0(String var0) {
      return fromHex(var0);
   }
}
